==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/zh_CN.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Todos" : "待办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 取消共享 {calendar} 给您",
    "You unshared calendar {calendar} from {user}" : "您取消共享给 {user} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 取消共享给 {uesr} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消共享日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您取消共享给组 {group} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 取消共享给组 {group} 的日历 {calendar}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Contact birthdays" : "联系人生日",
    "Invitation canceled" : "邀请已取消",
    "Hello %s," : "您好，%s，",
    "Invitation updated" : "邀请已更新",
    "When:" : "时间：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "Link:" : "链接：",
    "Contacts" : "联系人",
    "WebDAV" : "WebDAV",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址：%s",
    "Request ID: %s" : "请求 ID：%s",
    "Save" : "保存",
    "Send invitations to attendees" : "向参与者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "CalDAV server" : "日历服务",
    "Please make sure to properly set up the email settings above." : "请确保正确设置上面的电子邮件设置。"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/zh_CN.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Todos" : "待办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 取消共享 {calendar} 给您",
    "You unshared calendar {calendar} from {user}" : "您取消共享给 {user} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 取消共享给 {uesr} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消共享日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您取消共享给组 {group} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 取消共享给组 {group} 的日历 {calendar}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Contact birthdays" : "联系人生日",
    "Invitation canceled" : "邀请已取消",
    "Hello %s," : "您好，%s，",
    "Invitation updated" : "邀请已更新",
    "When:" : "时间：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "Link:" : "链接：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "Contacts" : "联系人",
    "Configures a CalDAV account" : "设置一个 CalDAV 账户",
    "Configures a CardDAV account" : "设置一个 CardDAV 账户",
    "WebDAV" : "WebDAV",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址：%s",
    "Request ID: %s" : "请求 ID：%s",
    "Save" : "保存",
    "Send invitations to attendees" : "向参与者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "CalDAV server" : "日历服务",
    "Please make sure to properly set up the email settings above." : "请确保正确设置上面的电子邮件设置。"
},
"nplurals=1; plural=0;");
